@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,12 +8,16 @@
 #
 # Thanks for using Enthought open source!
 
-from traits.observation.exception_handling import (     # noqa: F401
+from traits.observation.exception_handling import (
     pop_exception_handler,
     push_exception_handler,
 )
 
-from traits.observation.expression import (   # noqa: F401
+from traits.observation.exceptions import NotifierNotFound
+
+from traits.observation.expression import (
+    anytrait,
+    compile_expr,
     dict_items,
     list_items,
     match,
@@ -22,8 +26,13 @@ from traits.observation.expression import (   # noqa: F401
     trait,
 )
 
-from traits.observation.observe import (   # noqa: F401
+from traits.observation.observe import (
+    apply_observers,
     dispatch_same,
     observe,
 )
-from traits.observation.parsing import parse     # noqa: F401
+
+from traits.observation.parsing import (
+    compile_str,
+    parse,
+)
