@@ -1,23 +1,17 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2005-2013, Enthought, Inc.
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in /LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
-# ------------------------------------------------------------------------------
+
 import threading
 import time
 import warnings
 
-import six
-import six.moves as sm
-
-from traits import _py2to3
-
-from traits.testing.unittest_tools import unittest
 from traits.api import (
     Bool,
     Event,
@@ -28,6 +22,11 @@ from traits.api import (
     on_trait_change,
 )
 from traits.testing.api import UnittestTools
+# unittest_tools provides a reference to unittest for historical reasons, and
+# downstream packages may still be doing "from traits.testing.unittest_tools
+# import unittest". We keep this import as-is (instead of doing a simple
+# "import unittest") to make sure we don't break those packages.
+from traits.testing.unittest_tools import unittest
 from traits.util.api import deprecated
 
 
@@ -39,7 +38,7 @@ def old_and_dull():
     pass
 
 
-class TestObject(HasTraits):
+class ExampleObject(HasTraits):
 
     number = Float(2.0)
     list_of_numbers = List(Float)
@@ -55,7 +54,7 @@ class TestObject(HasTraits):
 
 class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
     def setUp(self):
-        self.test_object = TestObject()
+        self.test_object = ExampleObject()
 
     def test_when_using_with(self):
         """ Check normal use cases as a context manager.
@@ -225,19 +224,19 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
         """ Make sure that the traits context manager does not stop
         regular assertions inside the managed code block from happening.
         """
-        test_object = TestObject(number=16.0)
+        test_object = ExampleObject(number=16.0)
 
         with self.assertTraitDoesNotChange(test_object, "number"):
             self.assertEqual(test_object.number, 16.0)
 
-        with six.assertRaisesRegex(self, AssertionError, r"16\.0 != 12\.0"):
+        with self.assertRaisesRegex(AssertionError, r"16\.0 != 12\.0"):
             with self.assertTraitDoesNotChange(test_object, "number"):
                 self.assertEqual(test_object.number, 12.0)
 
     def test_special_case_for_count(self):
         """ Count equal to 0 should be valid but it is discouraged.
         """
-        test_object = TestObject(number=16.0)
+        test_object = ExampleObject(number=16.0)
 
         with self.assertTraitChanges(test_object, "number", count=0):
             test_object.flag = True
@@ -254,12 +253,12 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
 
         def thread_target(obj, count):
             "Fire obj.event 'count' times."
-            for _ in sm.range(count):
+            for _ in range(count):
                 obj.event = True
 
         threads = [
             threading.Thread(target=thread_target, args=(a, events_per_thread))
-            for _ in sm.range(thread_count)
+            for _ in range(thread_count)
         ]
 
         expected_count = thread_count * events_per_thread
@@ -285,13 +284,13 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
 
         def thread_target(obj, count):
             "Fire obj.event 'count' times."
-            for n in sm.range(count):
+            for n in range(count):
                 time.sleep(0.001)
                 obj.event = n
 
         threads = [
             threading.Thread(target=thread_target, args=(a, events_per_thread))
-            for _ in sm.range(thread_count)
+            for _ in range(thread_count)
         ]
 
         expected_count = thread_count * events_per_thread
@@ -304,10 +303,9 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
         for t in threads:
             t.join()
 
-        _py2to3.assertCountEqual(
-            self,
+        self.assertCountEqual(
             event_collector.events,
-            list(sm.range(events_per_thread)) * thread_count,
+            list(range(events_per_thread)) * thread_count,
         )
 
     def test_assert_trait_changes_async_failure(self):
@@ -322,12 +320,12 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
 
         def thread_target(obj, count):
             "Fire obj.event 'count' times."
-            for _ in sm.range(count):
+            for _ in range(count):
                 obj.event = True
 
         threads = [
             threading.Thread(target=thread_target, args=(a, events_per_thread))
-            for _ in sm.range(thread_count)
+            for _ in range(thread_count)
         ]
 
         expected_count = thread_count * events_per_thread
@@ -403,13 +401,16 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
         def old_and_dull_caller():
             old_and_dull()
 
-        # Pollute the registry by pre-calling the function.
-        old_and_dull_caller()
+        with warnings.catch_warnings(record=True):
+            warnings.simplefilter("always", DeprecationWarning)
 
-        # Check that we can still detect the DeprecationWarning.
-        with self.assertDeprecated():
+            # Pollute the registry by pre-calling the function.
             old_and_dull_caller()
 
+            # Check that we can still detect the DeprecationWarning.
+            with self.assertDeprecated():
+                old_and_dull_caller()
+
     def test_assert_not_deprecated_failures(self):
         with self.assertRaises(self.failureException):
             with self.assertNotDeprecated():
@@ -428,14 +429,18 @@ class UnittestToolsTestCase(unittest.TestCase, UnittestTools):
         def old_and_dull_caller():
             old_and_dull()
 
-        # Pollute the registry by pre-calling the function.
-        old_and_dull_caller()
+        with warnings.catch_warnings(record=True):
+            warnings.simplefilter("always", DeprecationWarning)
 
-        # Check that we can still detect the DeprecationWarning.
-        with self.assertRaises(self.failureException):
-            with self.assertNotDeprecated():
-                old_and_dull_caller()
+            # Pollute the registry by pre-calling the function.
+            old_and_dull_caller()
 
+            # Check that we can still detect the DeprecationWarning.
+            with self.assertRaises(self.failureException):
+                with self.assertNotDeprecated():
+                    old_and_dull_caller()
 
-if __name__ == "__main__":
-    unittest.main()
+    def test__catch_warnings_deprecated(self):
+        with self.assertWarns(DeprecationWarning):
+            with self._catch_warnings():
+                pass
