@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -56,6 +56,22 @@ class TestCTrait(unittest.TestCase):
             trait.default_value(), (DefaultValue.list_copy, [1, 2, 3])
         )
 
+    def test_validate_default_value_for_callable_and_args(self):
+
+        bad_values = [
+            None,
+            123,
+            (int, (2,)),
+            (int, 2, 3, 4),
+        ]
+
+        trait = CTrait(TraitKind.trait)
+        for value in bad_values:
+            with self.subTest(value=value):
+                with self.assertRaises(ValueError):
+                    trait.set_default_value(
+                        DefaultValue.callable_and_args, value)
+
     def test_default_value_for_set_is_deprecated(self):
         trait = CTrait(TraitKind.trait)
         with warnings.catch_warnings(record=True) as warn_msgs:
@@ -308,8 +324,33 @@ class TestCTrait(unittest.TestCase):
         self.assertEqual(foo.bar_changed[0], "baz")
 
     def test_failed_attribute_access(self):
+        # Double-underscore names are special-cased.
+        non_dunder_names = [
+            "non_existent",
+            "__non_existent",
+            "non_existent__",
+            "_non_existent_",
+            "__a__b_",
+            "_",
+        ]
+
+        dunder_names = [
+            "__package__",
+            "__a__",
+            "____",
+            "___",
+            "__",
+        ]
+
         ctrait = CTrait(0)
-        self.assertIsNone(ctrait.non_existent)
+        for name in non_dunder_names:
+            with self.subTest(name=name):
+                self.assertIsNone(getattr(ctrait, name))
+
+        for name in dunder_names:
+            with self.subTest(name=name):
+                with self.assertRaises(AttributeError):
+                    getattr(ctrait, name)
 
     def test_exception_from_attribute_access(self):
         # Regression test for enthought/traits#946.
