@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -21,6 +21,7 @@ from types import MethodType
 import weakref
 import sys
 
+from .constants import ComparisonMode, TraitKind
 from .trait_base import Uninitialized
 from .trait_errors import TraitNotificationError
 
@@ -325,7 +326,8 @@ class AbstractStaticChangeNotifyWrapper(object):
     def __call__(self, object, trait_name, old, new):
         """ Dispatch to the appropriate handler method. """
 
-        if old is not Uninitialized:
+        if _change_accepted(object, trait_name, old, new):
+
             # Extract the arguments needed from the handler.
             args = self.argument_transform(object, trait_name, old, new)
 
@@ -359,7 +361,7 @@ class AbstractStaticChangeNotifyWrapper(object):
         return False
 
 
-class StaticAnyTraitChangeNotifyWrapper(AbstractStaticChangeNotifyWrapper):
+class StaticAnytraitChangeNotifyWrapper(AbstractStaticChangeNotifyWrapper):
 
     # The wrapper is called with the full set of argument, and we need to
     # create a tuple with the arguments that need to be sent to the event
@@ -538,7 +540,8 @@ class TraitChangeNotifyWrapper(object):
         """ Dispatch a trait change event to a method listener. """
 
         obj_weak_ref = self.object
-        if (obj_weak_ref is not None) and (old is not Uninitialized):
+        if (obj_weak_ref is not None
+                and _change_accepted(object, trait_name, old, new)):
             # We make sure to hold a reference to the object before invoking
             # `getattr` so that the listener does not disappear in a
             # multi-threaded case.
@@ -553,7 +556,7 @@ class TraitChangeNotifyWrapper(object):
     def _notify_function_listener(self, object, trait_name, old, new):
         """ Dispatch a trait change event to a function listener. """
 
-        if old is not Uninitialized:
+        if _change_accepted(object, trait_name, old, new):
             self._dispatch_change_event(
                 object, trait_name, old, new, self.handler
             )
@@ -628,3 +631,37 @@ class NewTraitChangeNotifyWrapper(TraitChangeNotifyWrapper):
 
     def dispatch(self, handler, *args):
         Thread(target=handler, args=args).start()
+
+
+def _change_accepted(object, name, old, new):
+    """ Return true if notifications should be emitted for the change.
+
+    Parameters
+    ----------
+    object : HasTraits
+        The object on which the trait is changed.
+    name : str
+        The name of the trait changed.
+    old : any
+        The old value
+    new : any
+        The new value
+
+    Returns
+    -------
+    accepted : bool
+        Whether the event should be emitted.
+    """
+    if old is Uninitialized:
+        return False
+
+    trait = object._trait(name, 2)
+    if (trait.type == TraitKind.trait.name
+            and trait.comparison_mode == ComparisonMode.equality):
+        try:
+            return bool(old != new)
+        except Exception:
+            # Maybe do something else about the exception
+            # enthought/traits#1230
+            pass
+    return True
